/*
 * Copyright 2004-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hdiv.web.servlet.tags.form;

import javax.servlet.jsp.JspException;

import org.hdiv.dataComposer.IDataComposer;
import org.springframework.web.servlet.tags.form.PasswordInputTag;
import org.springframework.web.servlet.tags.form.TagWriter;

/**
 * Databinding-aware JSP tag for rendering an HTML '<code>input</code>'
 * element with a '<code>type</code>' of '<code>password</code>'.
 *
 * @author Gorka Vicente
 * @since HDIV 2.0
 * @see org.springframework.web.servlet.tags.form.PasswordInputTag
 */
public class PasswordInputTagHDIV extends PasswordInputTag {

	private static final String DATA_COMPOSER = "dataComposer";
	
	/**
	 * The {@link PasswordInputTag} only writes it's value if the
	 * {@link #setShowPassword(boolean) 'showPassword'} property value is
	 * {@link Boolean#TRUE true}.
	 */
	protected void writeValue(TagWriter tagWriter) throws JspException {
		 
		IDataComposer dataComposer = (IDataComposer) this.pageContext.getRequest().getAttribute(DATA_COMPOSER);		
		dataComposer.compose(super.getName(), "", true, "password");
		
		super.writeValue(tagWriter);
	}
		
}
